#!/usr/bin/python3

from pathlib import Path

from loguru import logger

from baobaxia.root import bbx
from baobaxia.util import (
    calculate_md5,
    processar_arquivo_json,
    processar_arquivo_json_remove_attribute,
    processar_arquivo_json_indent
    )


def migrate_midias_reset_content():
    """Migra os midias para novo formato."""

    processar_arquivo_json(
        caminho=bbx.config.data_path,
        atributo="content",
        novo_valor=[],
        excluidos=[".git", "OLD"],
        incluidos=["acervo"],
    )

    bbx.reload_balaios()

    saberes = bbx.find_midias(page_size=999, page_index=1)

    for item in saberes["items"]:
        item.content = []
        logger.debug(f"ITEM: {item}")
        for midiafile in [
            f
            for f in (
                bbx.get_balaio_mucua_path(
                    balaio_smid=item.balaio_smid,
                    mucua_smid=item.mucua_smid,
                    relative=False,
                )
                / item.path
            ).glob("*")
            if not (
                f.name.startswith(bbx.config.saber_file_ext)
                or "_thumb" in f.name
            )
        ]:
            file_size = Path(midiafile).stat().st_size
            extension = Path(midiafile).suffix
            hash_sum = (
                f"MD5E-s{file_size}--{calculate_md5(midiafile)}{extension}"
            )
            item.content.append(
                {"filename": midiafile.name, "hash_sum": hash_sum}
            )
            mocambola = bbx.get_mocambola(
                username=item.creator,
                balaio_smid=item.balaio_smid,
                mucua_smid=item.mucua_smid,
            )
            bbx.put_midia(
                item.balaio_smid, item.mucua_smid, item, mocambola=mocambola
            )

def migrate_saberes_remove_attribute(attribute):

    processar_arquivo_json_remove_attribute(
        caminho=bbx.config.data_path,
        atributo=attribute,
        excluidos=[".git", "OLD"],
    )

def migrate_saberes_indent():

    processar_arquivo_json_indent(
        caminho=bbx.config.data_path,
        excluidos=[".git", "OLD"],
    )

    
    
