#!/usr/bin/env python3
from loguru import logger

from baobaxia.utils.strings import parse_tags


class TestClassBlogItem:
    item_smid = None
    balaio = None
    mucua = None
    data = {
        "name": "Um artigo no bbx",
        "path": "blog",
        "creator": "exu do bbx",
        "is_public": True,
        "titulo": "Um artigo no bbx",
        "resumo": "Aqui nos resume e..",
        "texto": "Aqui tem a história toda. :) ",
        "status": "draft",
        "tags": "um, dois",
    }

    def _find_blog_item(self, client):
        response_find = client.get("/api/v2/blog/find")
        assert response_find.status_code == 200
        return response_find.json()

    def _get_balaio_mucua(self, bbx):
        return bbx.default_balaio.smid, bbx.default_mucua.smid

    def test_create_blog_item(self, baobaxia_base, token, client):
        balaio = baobaxia_base.default_balaio.smid
        mucua = baobaxia_base.default_mucua.smid
        data = self.data
        data["balaio_smid"] = balaio
        data["mucua_smid"] = mucua

        _header = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {token}",
        }

        response = client.post(
            f"/api/v2/{balaio}/{mucua}/blog/artigo",
            json=data,
            headers=_header,
        )
        assert response.status_code == 200

    def test_find_blog_item(self, client):
        response = self._find_blog_item(client)
        assert response["item_count"] == 1

    def test_get_blog_item(self, baobaxia_base, client):
        response = self._find_blog_item(client)
        item_smid = response["items"][0]["smid"]
        balaio, mucua = self._get_balaio_mucua(baobaxia_base)

        logger.debug(item_smid)

        response = client.get(
            f"/api/v2/{balaio}/{mucua}/blog/artigo/{item_smid}"
        )

        assert response.status_code == 200
        r = response.json()
        # assert r["path"] == f"blog/""
        assert r["name"] == self.data["name"]
        # assert r["creator"] == self.data["creator"]
        assert bool(r["is_public"]) == bool(self.data["name"])
        assert r["titulo"] == self.data["titulo"]
        assert r["resumo"] == self.data["resumo"]
        assert r["texto"] == self.data["texto"]
        assert r["status"] == self.data["status"]
        assert r["tags"] == parse_tags(self.data["tags"])
